@@ -24,9 +24,8 @@ class dataset_loader:
         self.token = token
         self.symbols_list = None  # 股票列表
         self.symbol_index = dict()  # 股票时间索引
-        self.filter = set()
+        self.filter = set()  # 股票的过滤集
         self.data = pd.DataFrame()
-        pass
 
     def __daily_data(self, symbol, start, end):
         """
@@ -42,7 +41,8 @@ class dataset_loader:
             api=api,
             start_date=str(start) + "0101",
             end_date=str(end) + "1231",
-            asset="E",  # E:沪深港通资金流向 F:港股通资金流向
+            adjfactor=True,
+            asset="E",  # 证券类型 E:股票和交易所基金，I:沪深指数,C:数字货币,FT:期货 FD:基金/O期权/H港股/CB可转债
             freq="D",  # D:日线 W:周 M:月
             adj="hfq",  # 不复权:None 前复权:qfq 后复权:hfq
             retry_count=99  # 重试次数
@@ -100,19 +100,23 @@ class dataset_loader:
         if os.path.exists(data_path):
             print("读取本地数据集")
             self.data = pd.read_csv(data_path)
-
-            # 本地数据缺少股票代码的时间索引
         else:
             print("从互联网获取数据集")
             symbols_list = self.__get_symbols_by_wc(self.question, columns=['股票代码'])
-            print("从互联网获取数据集")
+
             for index, symbol in enumerate(symbols_list['股票代码'].unique()):
                 print("数据进度百分比:%s" % (index / len(symbols_list['股票代码'].unique()) * 100), end="\r")
                 # 获取股票代码的符合的年数据
-                symbol_data = symbols_list[symbols_list['股票代码'] == symbol]
-                # 获取股票代码的年数据的时间集合
-                self.symbol_index.update({symbol: num_kit.date_split(symbol_data['trade_date'])})
+                # symbol_data = symbols_list[symbols_list['股票代码'] == symbol]
+                # # 获取股票代码的年数据的时间集合
+                # self.symbol_index.update({symbol: num_kit.date_split(symbol_data['trade_date'])})
                 self.data = pd.concat([self.data, self.__daily_data(symbol, self.start, self.end)])
+        # 重置索引
+        self.data = self.data.reset_index(drop=True)
+        # 将日期转换为字符串
+        self.data['trade_date'] = self.data['trade_date'].apply(lambda x: str(x))
+        # 将数据里的数字类型转换为float 保留两位小数
+        self.data = self.data.applymap(lambda x: round(float(x), 2) if isinstance(x, (int, float)) else x)
         return self.data
 
     def observe(self, mlflow):
@@ -124,7 +128,7 @@ class dataset_loader:
         mlflow.log_text("data_report", "\n".join(self.__data_report()))
         # 新增数据集
 
-    def save(self, file_path='../data/dataset.csv'):
+    def save(self, file_path='../data/data.csv'):
         """
         保存数据集
         :param path:
